

clear all

*User input location of CodePackage
global userpath="..."

global parent="$userpath\CodePackage"
global outputpath="$userpath\CodePackage\output"

cd "$parent"

/******************************
1.  Load in prices from different sources, including the BEA Health Care Satellite Account for 2017.
******************************/

*Load in 2017 Data from HCSA
import excel using "$parent\ExternalData\2017-Blended-Account-Release-TableEdited.xlsx", clear firstrow sheet("Price Indexes Blended")
drop D-S
gen CCSChapterNumber=Chapnum
gen CCSChapter=BlendedAccount

*Create Index for 2017 by disease
gen hcsa_dis_pricegrowth=y2017/y2000
egen hcsa_overalldis_pricegrowth=max(hcsa_dis_pricegrowth*(Chapnum==0))
*Use overall economy wide GDP deflator from BEA to deflate the growth rate.
gen gdppriceindexgrowth=1.380765733
replace hcsa_dis_pricegrowth=hcsa_dis_pricegrowth/gdppriceindexgrowth
replace hcsa_overalldis_pricegrowth=hcsa_overalldis_pricegrowth/gdppriceindexgrowth
drop if Chapnum==0
gen chapnum=CCSChapterNumber

keep chapnum hcsa_dis_pricegrowth hcsa_overalldis_pricegrowth
sort chapnum
*save price data
save "$parent\ExternalData\BlendedAccountPrices2017", replace


*Load in 2017 Data from HCSA and construct shares
import excel using "$parent\ExternalData\2017-Blended-Account-Release-TableEdited.xlsx", clear firstrow sheet("Expenditures Blended")
drop y2001-S
gen All_DollarsChapter2017=y2017
gen All_DollarsChapter2000=y2000
gen CCSChapterNumber=Chapnum
gen CCSChapter=BlendedAccount
drop if Chapnum==0

egen All_Dollars2017=sum(All_DollarsChapter2017)
egen All_Dollars2000=sum(All_DollarsChapter2000)
gen share_chapter2017=All_DollarsChapter2017/All_Dollars2017
gen share_chapter2000=All_DollarsChapter2000/All_Dollars2000
keep CCSChapterNumber CCSChapter share_chapter2017 share_chapter2000 All_Dollars2017 All_Dollars2000

table CCSChapter, c(mean share_chapter2017 mean share_chapter2000 )
gen chapnum=CCSChapterNumber
sort chapnum
merge 1:1 chapnum using "$parent\ExternalData\BlendedAccountPrices2017"
drop _merge
sort chapnum
*save share data
save "$parent\ExternalData\BlendedAccountSpendingAndPrices2017", replace



*PCE - health care specific price index, including all health related consumption
import delimited "$parent\ExternalData\price_data_by_function_pce2_10_21.csv", clear
rename ïyear YearOfCurrency
rename health PCEhealthindex
replace PCEhealthindex=PCEhealthindex/100
egen index2017=max((YearOfCurrency==2017)*PCEhealthindex)
replace PCEhealthindex=PCEhealthindex/index2017
drop index2017
summ PCEhealthindex, detail
sort YearOfCurrency
save "$parent\ExternalData\pcehealth_index", replace

*Load OECD exchange rate data
import delimited  "$parent\ExternalData\ExchangeRateData2_10_2021.csv", clear
rename ïlocation location
*Adjust names for merging
gen CurrencyCountry=""
replace CurrencyCountry=""
replace CurrencyCountry="United States" if location=="USA"
replace CurrencyCountry="Euro" if location=="EU28"
replace CurrencyCountry="United Kingdom" if location=="GBR"
replace CurrencyCountry="Canada" if location=="CAN"
replace CurrencyCountry="Australia" if location=="AUS"
replace CurrencyCountry="Sweden" if location=="SWE"
replace CurrencyCountry="Japan" if location=="JPN"
replace CurrencyCountry="New Zealand" if location=="NZL"
replace CurrencyCountry="Switzerland" if location=="CHE"
replace CurrencyCountry="China" if location=="CHN"
replace CurrencyCountry="Brazil" if location=="BRA"
replace CurrencyCountry="Norway" if location=="NOR"
replace CurrencyCountry="Netherlands" if location=="NLD"
replace CurrencyCountry="Mexico" if location=="MEX"
replace CurrencyCountry="Denmark" if location=="DNK"
replace CurrencyCountry="South Korea" if location=="KOR"
replace CurrencyCountry="France" if location=="ZAF"
replace CurrencyCountry="Poland" if location=="POL"
replace CurrencyCountry="Thailand" if location=="THA"
replace CurrencyCountry="Taiwan" if location=="TWN"
replace CurrencyCountry="Singapore" if location=="SGP"
replace CurrencyCountry="Denmark" if location=="DNK"
replace CurrencyCountry="ECU" if location=="ECU"
replace CurrencyCountry="France" if location=="FRA"
replace CurrencyCountry="India" if location=="IND"
replace CurrencyCountry="South Africa" if location=="ZAF"

drop if missing(CurrencyCountry)

rename time YearOfCurrency
rename value OECDexchangeindex
replace OECDexchangeindex=1/OECDexchangeindex
summ OECDexchangeindex, detail
keep YearOfCurrency  CurrencyCountry OECDexchangeindex
sort YearOfCurrency
save "$parent\ExternalData\Exchange_index", replace

/*************************************
*Load currency data that was available in previous downloaded version of Tufts CEAR database.
*The currency adjustment was that same as that use by HJP.  This data was not available in future version of
*the database so we used exchange data from the OECD source, which matches closely with this prior data.
******************************************************/

*Import older version and keep indexes.
*import excel "\\serv571c\Research2\Dunn\TuftsCEAData\CEAR_ArticlesCopy.xlsx", firstrow clear
*keep ArticleID FEF CPI
*sort ArticleID
*save "\\serv571c\Research2\Dunn\TuftsCEAData\OldCurrencyData", replace

/************************************
2.  Load in article data
************************************/

import excel "$parent\Private_CEAR_Data\CEAR_Articles5_14_2020.xlsx", firstrow clear


*Estimate reported in paper of the share of articles available across years
tab PubYear
tab PubYear if PubYear>=2004

/*******************************
3.  Categorize articles based on words in title and abstract
*********************************/
gen randomabstract=strrpos(lower(Abstract),"random")>0
gen randomtitle=strrpos(lower(Title),"random")>0
gen random=randomabstract | randomtitle


gen metaabstract=strrpos(lower(Abstract),"meta-")>0
gen metatitle=strrpos(lower(Title),"meta-")>0
gen meta2abstract=strrpos(lower(Abstract),"meta ")>0
gen meta2title=strrpos(lower(Title),"meta ")>0


gen markovabstract=strrpos(lower(Abstract),"markov")>0
gen markovtitle=strrpos(lower(Title),"markov")>0
gen simulationabstract=strrpos(lower(Abstract),"simulation")>0
gen simulationtitle=strrpos(lower(Title),"simulation")>0

gen meta=metaabstract | metatitle | metaabstract | metatitle

gen markov= markovabstract | markovtitle
gen simulation=simulationabstract | simulationtitle

gen trialabstract=strrpos(lower(Abstract),"trial")>0
gen trialtitle=strrpos(lower(Title),"trial")>0
gen trial=trialabstract | trialtitle

gen truerandom=(random | trial) & ~meta
gen truesimulation=(markov  | simulation) & ~truerandom & ~meta
gen truemeta=meta 

gen studytype="Other"
replace studytype="Randomized" if truerandom
replace studytype="Simulation" if truesimulation
replace studytype="Meta-Analysis" if truemeta


/*******************************
4.  For imputation when currency year is missing, assume currency year is 2 years prior to publication.
*********************************/
gen rYearOfCurrency=real(YearOfCurrency)
drop YearOfCurrency
rename rYearOfCurrency YearOfCurrency
replace YearOfCurrency=PubYear-2 if missing(YearOfCurrency)
tab PubYear

/*******************************
5.  Keep a subset of key economic variables - and save main article data.  Merge in currency data that was available from prior versions of Tufts CEAR data
*********************************/
keep PubYear YearOfCurrency ArticleID DisChapter1 Intervention* Review Rating Sponsorship* Country CurrencyCountry studytype Diseaseorhealthintervention DisCode1 
sort ArticleID
merge 1:1 ArticleID using "$parent\ExternalData\OldCurrencyData"
tab _merge
drop _merge
sort ArticleID
save "$parent\articledata", replace

/*******************************
6.  Load in CEAR ratio data and merge with article data
*********************************/
import excel "$parent\Private_CEAR_Data\CEAR_Ratios5_14_2020.xlsx", firstrow clear
sort ArticleID 
merge m:1 ArticleID using "$parent\articledata"
drop if _merge==2
drop _merge


/*******************************
7.  Merge in associated over-time and cross-country indexes
*********************************/

*PCE health by function
sort YearOfCurrency
merge m:1 YearOfCurrency using "$parent\ExternalData\pcehealth_index"
drop if _merge==2
drop _merge


*OECD exchange rate index
sort YearOfCurrency CurrencyCountry
merge m:1 YearOfCurrency CurrencyCountry using "$parent\ExternalData\Exchange_index"

drop if _merge==2



*Categorize high income based on world bank classification:
*https://datahelpdesk.worldbank.org/knowledgebase/articles/906519-world-bank-country-and-lending-groups
*based on classification and data for calendar year 2019
gen highincome=Country=="United States" | Country=="Belgium" | Country=="Canada" | Country=="Austria" | Country=="Australia" | Country=="European Union" | Country=="Finland" | Country=="France" | Country=="Germany" | Country=="Japan" | Country=="Italy" | Country=="Israel" | Country=="Netherlands" | Country=="New Zealand" | Country=="Norway" | Country=="United Kingdom" | Country=="Switzerland" | Country=="Switzerland" | Country=="Spain" | Country=="South Korea" | Country=="Denmark"  | Country=="Denmark" |Country=="Greece" | Country=="Iceland" | Country=="Sweden" | Country=="Singapore" | Country=="Portugal" | Country=="Chile" | Country=="Croatia" | Country=="Czech Republic" | Country=="Poland"  | Country=="Russia" | Country=="Slovenia" | Country=="Slovakia" | Country=="Scotland" | Country=="Saudi Arabia" | Country=="Taiwan" | Country=="Lithuania" | Country=="Ireland" | Country=="Hong Kong" | Country=="Europe" | Country=="England" | Country=="United Arab Emirates" | Country=="Korea" | Country=="Estonia" | Country=="Cyprus"


/*******************************
8.  Apply exchange rate and over-time price indexes.  The default was to use the exchange
data from the CEAR data, but applied some corrections for a handful of problem observations.
In general the OECD exchange data and the data from CEAR were extremely close.
*********************************/

*Exchange rate is in U.S. Dollars per Foreign Currency

/*Comparison of old currency available in CEAR data with updated currency data from OECD.

*https://fxtop.com/en/historical-currency-converter.php?A=100&C1=FRA&C2=USD&DD=&MM=&YYYY=1993&B=1&P=&I=1&btnOK=Go%21
*/

gen percentdiff=abs(FEF-OECDexchangeindex)/((FEF+OECDexchangeindex)/2)
summ percentdiff if percentdiff>.2 & ~missing(percentdiff), detail

***************************
*Correct exchange rate calculations.
***************************
*Outlier/Mistake for New Zealand in 2011.  Use OECD exchange index
*table YearOfCurrency if CurrencyCountry=="New Zealand", c(mean  FEF mean OECDexchangeindex)
replace FEF=OECDexchangeindex if CurrencyCountry=="New Zealand" & YearOfCurrency==2011
*The U.S. exchange rate is normalized to one in all of the data.
replace FEF=1 if ~missing(percentdiff) & percentdiff>.2 & CurrencyCountry=="United States" & ~missing(CurrencyCountry)
replace FEF=OECDexchangeindex if (percentdiff>.2) & CurrencyCountry=="Euro" & ~missing(percentdiff)
*table YearOfCurrency if CurrencyCountry=="Canada", c(mean  FEF mean OECDexchangeindex)
*Use the OECD exchange data where the CEAR exchange data is not available.
replace FEF=OECDexchangeindex if missing(FEF)
gen rate_adjust=PCEhealthindex/FEF if ~missing(FEF)
replace rate_adjust=PCEhealthindex/OECDexchangeindex if missing(FEF)

/***************************
*Place all dollar estimates into U.S. currency for 2017
*Our method uses PCE health index - put back into correct U.S. dollar amount for 2017
***************************/
for var TotalCostsPerPerson InterventionTotalCostsPerPerson ComparatorTotalCostsPerPerson: replace X=X/rate_adjust

*The variable QALYFinal is the ICER calculated in the study.  This also needs to be adjusted to 2017 U.S. dollars.
gen ICERFinaladjust=QALYFinal/rate_adjust


/*********************************
9.  Mark problem abservations and do associated cleaning steps, following steps of HJP
*********************************/

*Order data so key data elements appear first.
order TotalCostsPerPerson QALYsPerPerson InterventionTotalCostsPerPerson ComparatorTotalCostsPerPerson InterventionQALYsPerPerson ComparatorQALYsPerPerson

*Mark as "problem" if it is missing any of the key variables.
gen problem=missing(InterventionTotalCostsPerPerson) | missing(ComparatorTotalCostsPerPerson) | missing(InterventionQALYsPerPerson) | missing(ComparatorQALYsPerPerson)

*Construct our own ICER estimate based on components observed
gen ICER=(InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)/(InterventionQALYsPerPerson-ComparatorQALYsPerPerson)
replace ICER=(TotalCostsPerPerson)/(QALYsPerPerson) if missing(ICER)

*Drop negative costs, extreme values that are above $10 million, and QALYs greater than 100 years
replace ComparatorTotalCostsPerPerson=.  if ComparatorTotalCostsPerPerson<0
replace InterventionTotalCostsPerPerson=. if InterventionTotalCostsPerPerson<0
replace ComparatorTotalCostsPerPerson=. if ComparatorTotalCostsPerPerson>=10000000
replace InterventionTotalCostsPerPerson=. if InterventionTotalCostsPerPerson>=10000000
replace InterventionQALYsPerPerson=. if  abs(InterventionQALYsPerPerson)>=100
replace ComparatorQALYsPerPerson=. if abs(ComparatorQALYsPerPerson)>=100

*Drop if price per QALY or ICER is above $10 million
gen priceqalyinnovation=InterventionTotalCostsPerPerson/InterventionQALYsPerPerson
gen priceqalycomparator=ComparatorTotalCostsPerPerson/ComparatorQALYsPerPerson
replace priceqalyinnovation=. if priceqalyinnovation>=10000000
replace priceqalycomparator=. if priceqalycomparator>=10000000
replace ICERFinaladjust=. if abs(ICERFinaladjust)>=10000000
replace ICER=. if abs(ICER)>=10000000
replace QALYinCurrentUSDollars=. if abs(QALYinCurrentUSDollars)>=10000000

*Drop negative QALYs  Following HJP
replace InterventionQALYsPerPerson=. if   InterventionQALYsPerPerson<0
replace  ComparatorQALYsPerPerson=.  if ComparatorQALYsPerPerson<0


/*********************************
10.  Construct categories for the data
*********************************/
*Categories for first table
*Broad disease categories
tab DisChapter
gen chapter="Musculoskeletal/Rheumatologic" if strpos(DisChapter,"musculoskeletal")~=0
replace chapter="Maternal/Child" if strpos(DisChapter,"Pregnancy")~=0 | strpos(DisChapter,"Congenital")~=0  |  strpos(DisChapter,"perinatal")~=0 
replace chapter="Neuro-Psychiatric/Neurological" if strpos(DisChapter,"nervous")~=0 | strpos(DisChapter,"mental")~=0
replace chapter="Endocrine Disorders" if strpos(DisChapter,"Endocrine")~=0
replace chapter="Cardiovascular" if strpos(DisChapter,"circulatory")~=0
replace chapter="Digestive" if strpos(DisChapter,"digestive")~=0
replace chapter="Respiratory" if strpos(DisChapter,"respiratory")~=0
replace chapter="Malignant Neoplasms" if strpos(DisChapter,"Neoplasms")~=0
replace chapter="Sense Organ" if strpos(DisChapter," ear ")~=0 | strpos(DisChapter," eye ")~=0 
replace chapter="Infectious" if strpos(DisChapter,"infectious")~=0
replace chapter="Other" if missing(chapter)

*Contruct disease chapters/categories that correspond to HCSA disease chapters
gen chapnum=1 if strpos(DisChapter, "I: Certain inf")~=0
gen chap="Infectious and parasistic diseases" if chapnum==1
replace chapnum=2 if strpos(DisChapter, "II: Neoplasms")~=0
replace chap="Neoplasms" if chapnum==2
replace chapnum=4 if strpos(DisChapter, "III: Diseases of the blood")~=0
replace chap="Diseases of the blood and blood-forming organs" if chapnum==4
replace chapnum=3 if strpos(DisChapter, "IV: Endocrine")~=0
replace chap="Endocrine, nutritional, and metabolic" if chapnum==3
replace chapnum=7 if strpos(DisChapter, "IX: Diseases of the circulatory")~=0
replace chap="Diseases of the circulatory system" if chapnum==7
replace chapnum=5 if strpos(DisChapter, "V: Mental")~=0
replace chap="Mental Illness" if chapnum==5
replace chapnum=6 if strpos(DisChapter, "VI: Diseases of the nervous")~=0
replace chap="Diseases of the nervous system and sense organs" if chapnum==6
replace chapnum=6 if strpos(DisChapter, "VII: Diseases of the eye")~=0
replace chap="Diseases of the nervous system and sense organs" if chapnum==6
replace chapnum=6 if strpos(DisChapter, "VIII: Diseases of the ear")~=0
replace chap="Diseases of the nervous system and sense organs" if chapnum==6
replace chapnum=8 if strpos(DisChapter, "X: Diseases of the respiratory")~=0
replace chap="Diseases " if chapnum==8
replace chapnum=9 if strpos(DisChapter, "XI: Diseases of the digestive")~=0
replace chap="Diseases of the digestive system" if chapnum==9
replace chapnum=12 if strpos(DisChapter, "XII: Diseases of the skin")~=0
replace chap="Diseases of the skin and subcutaneous tissue" if chapnum==12
replace chapnum=13 if strpos(DisChapter, "XIII: Diseases of the musculoskeletal")~=0
replace chap="Diseases of the musculoskeletal system and connective tissue" if chapnum==13
replace chapnum=10 if strpos(DisChapter, "XIV: Diseases of the genitourinary")~=0
replace chap="Diseases of the genitourinary system" if chapnum==10
replace chapnum=16 if strpos(DisChapter, "XIX: Injury, poisoning and certain")~=0
replace chap="Injury and poisoning" if chapnum==16
replace chapnum=11 if strpos(DisChapter, "XV: Pregnancy, childbirth and ")~=0
replace chap="Complications of pregnancy, childbirth, and the puerperium" if chapnum==11
replace chapnum=15 if strpos(DisChapter, "XVI: Certain conditions originating")~=0
replace chap="Certain conditions originating in the perinatal period" if chapnum==15
replace chapnum=14 if strpos(DisChapter, "XVII: Congenital malformations, def")~=0
replace chap="Congenital anomolies" if chapnum==14
replace chapnum=17 if strpos(DisChapter, "XVIII: Symptoms, signs and abnormal")~=0
replace chap="Symptoms, signs and abnormal" if chapnum==17
replace chapnum=18 if strpos(DisChapter, "XX: External causes of morbidity")~=0
replace chap="Other conditions" if chapnum==18
replace chapnum=18 if strpos(DisChapter, "XXI: Factors influencing health")~=0
replace chap="Other conditions" if chapnum==18
replace chapnum=18 if strpos(DisChapter, "00: Interventions otherwise not")~=0
replace chap="Other conditions" if chapnum==18
tab DisChapter if missing(chapnum)

*Contruct type of intervention categories
gen typeintervention="Education"  if InterventionHealthEducation
replace typeintervention="Diagnositc"  if InterventionDiagnostic
replace typeintervention="Care Delivery" if InterventionCareDelivery
replace typeintervention="Screening"  if InterventionScreening
replace typeintervention="Surgical"  if InterventionSurgical
replace typeintervention="Immunization"  if InterventionImmunization
replace typeintervention="Device"  if InterventionMedicalDevice
replace typeintervention="Pharmaceutical"  if InterventionPharmaceutical
replace typeintervention="Procedure"  if InterventionMedicalProcedure

*Construct type of funding categories
gen typesponsor="Government"  if SponsorshipGovernment
replace typesponsor="Foundation"  if SponsorshipFoundation
replace typesponsor="Pharma or Device Manuf." if SponsorshipPharmOrDevice
replace typesponsor="Health Care Organization"  if SponsorshipHealthCare
replace typesponsor="Prof Member Organization"  if SponsorshipProfMembOrg
replace typesponsor="Other" if missing(typesponsor)


*Assign Associated Labels for the categories
egen ntypeintervention=group(typeintervention)
label define interventionsfull 1 "Care Delivery" 2 "Device" 3 "Diagnostic" 4 "Education"  5 "Immunization"  6 "Pharmaceutical" 7 "Procedure" 8 "Screening" 9 "Surgical"
gen missingtype=missing(typeintervention)
label value ntypeintervention interventionsfull


/*********************************
11.  Merge on disease spending information from the HCSA
*********************************/
sort chapnum
drop _merge
merge m:1 chapnum using "$parent\ExternalData\BlendedAccountSpendingAndPrices2017"


/*********************************
12.  Construct variables needed for later analysis.  primarily for hedonic analysis
*********************************/
gen lInterventionTotalCostsPerPerson=log(InterventionTotalCostsPerPerson)
gen lInterventionQALYsPerPerson=log(InterventionQALYsPerPerson)
gen lComparatorTotalCostsPerPerson=log(ComparatorTotalCostsPerPerson)
gen  lComparatorQALYsPerPerson=log(ComparatorQALYsPerPerson)
gen lsurvivalbenefit=log(InterventionQALYsPerPerson)-log(ComparatorQALYsPerPerson)
gen lcostchange=lInterventionTotalCostsPerPerson-lComparatorTotalCostsPerPerson
gen survivalbenefit=InterventionQALYsPerPerson-ComparatorQALYsPerPerson
gen costchange=InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson
egen nchapter=group(chapter)
egen disease=group(Diseaseorhealthintervention)

/*********************************
13.  Descriptive Stats Table
*********************************/

*************************************
*Table 1.  Descriptive Stats for Table 
*************************************
tabstat QALYinCurrentUSDollars, stats(mean median p5 p95 sd n)
tabstat InterventionQALYsPerPerson, stats(mean median p5 p95 sd n)
tabstat  ComparatorQALYsPerPerson, stats(mean median p5 p95 sd n)
tabstat InterventionTotalCostsPerPerson, stats(mean median p5 p95 sd n)
tabstat ComparatorTotalCostsPerPerson, stats(mean median p5 p95 sd n)
tabstat  priceqalyinnovation, stats(mean median p5 p95 sd n)
tabstat  priceqalycomparator, stats(mean median p5 p95 sd n)

*Higher Price and Higher QALY
tabstat ICERFinaladjust if QALYQuadrant==2, stats(mean median p5 p95 sd n)
*Lower Price and Higher QALY
tabstat ICERFinaladjust if QALYQuadrant==4, stats(mean median p5 p95 sd n)
*Higher Price and lower QALY
tabstat ICERFinaladjust if QALYQuadrant==1, stats(mean median p5 p95 sd n)
*Lower Price and Lower QALY
tabstat ICERFinaladjust if QALYQuadrant==3, stats(mean median p5 p95 sd n)


*Higher Price and Higher QALY
tabstat ICERFinaladjust if QALYQuadrant==2 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)
*Lower Price and Higher QALY
tabstat ICERFinaladjust if QALYQuadrant==4 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)
*Higher Price and lower QALY
tabstat ICERFinaladjust if QALYQuadrant==1 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)
*Lower Price and Lower QALY
tabstat ICERFinaladjust if QALYQuadrant==3 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)


tabstat ICERFinaladjust if QALYQuadrant==1 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)
tabstat ICERFinaladjust if QALYQuadrant==2 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)
tabstat ICERFinaladjust if QALYQuadrant==3 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)
tabstat ICERFinaladjust if QALYQuadrant==4 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)


tabstat QALYsPerPerson TotalCostsPerPerson if abs(QALYsPerPerson)<50, by(QALYQuadrant) stats(mean median n)
tabstat QALYsPerPerson if abs(QALYsPerPerson)<50, stats(mean median p5 p95 sd n)
tabstat QALYsPerPerson if abs(QALYsPerPerson)<50 & ~missing(ComparatorQALYsPerPerson) & ~missing(InterventionQALYsPerPerson) & ~missing(InterventionTotalCostsPerPerson) & ~missing(ComparatorQALYsPerPerson), stats(mean median p5 p95 sd n)
tabstat ICER, stats(mean median p5 p95 sd n)



/*********************************
14.  Construct Quality-Adjusted Price Indexes
*********************************/

********************
*Baseline Unadjusted Index
********************
gen unadjustedindex=InterventionTotalCostsPerPerson/ComparatorTotalCostsPerPerson

*************************************************
*Welfare Change for reservation price method and $50,000 VSLY
*************************************************
gen welfarechange_50=-1*((InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)-50000*(InterventionQALYsPerPerson-ComparatorQALYsPerPerson))
gen adjustment2_50=welfarechange_50/(welfarechange_50+InterventionTotalCostsPerPerson)
gen corr_qualityadjustedprice50_2=1-adjustment2_50

summ corr_qualityadjustedprice50_2, detail
gen p99_2=r(p99)
gen p1_2=r(p1)
gen outlier50_2=corr_qualityadjustedprice50>p99_2 | corr_qualityadjustedprice50<p1_2

summ corr_qualityadjustedprice50_2 if  ~outlier50_2, detail

*************************************************
*Welfare Change for reservation price method and $100,000 VSLY
*************************************************
gen welfarechange_100=-1*((InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)-100000*(InterventionQALYsPerPerson-ComparatorQALYsPerPerson))
gen adjustment2_100=welfarechange_100/(welfarechange_100+InterventionTotalCostsPerPerson)
gen corr_qualityadjustedprice100_2=1-adjustment2_100

summ corr_qualityadjustedprice100_2, detail
gen p100_99_2=r(p99)
gen p100_1_2=r(p1)
gen outlier100_2=corr_qualityadjustedprice100>p100_99_2 | corr_qualityadjustedprice100<p100_1_2

summ corr_qualityadjustedprice100_2 if  ~outlier100_2, detail

*************************************************
*Welfare Change for reservation price method and $150,000 VSLY
*************************************************
gen welfarechange_150=-1*((InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)-150000*(InterventionQALYsPerPerson-ComparatorQALYsPerPerson))
gen adjustment2_150=welfarechange_150/(welfarechange_150+InterventionTotalCostsPerPerson)
gen corr_qualityadjustedprice150_2=1-adjustment2_150

summ corr_qualityadjustedprice150_2, detail
gen p150_99_2=r(p99)
gen p150_1_2=r(p1)
gen outlier150_2=corr_qualityadjustedprice150>p150_99_2 | corr_qualityadjustedprice150<p150_1_2

summ corr_qualityadjustedprice150_2 if ~outlier150_2, detail


*************************************************
*COLI Laspeyres index price method and $50,000 VSLY
*************************************************
gen correct_qualityadjustedprice50=(InterventionTotalCostsPerPerson-50000*(InterventionQALYsPerPerson-ComparatorQALYsPerPerson))/ComparatorTotalCostsPerPerson

summ correct_qualityadjustedprice50, detail
gen p99=r(p99)
gen p1=r(p1)
gen outlier50=correct_qualityadjustedprice50>p99 | correct_qualityadjustedprice50<p1
summ correct_qualityadjustedprice50 if ~outlier50, detail

*************************************************
*COLI Laspeyres index price method and $100,000 VSLY
*************************************************
gen correct_qualityadjustedprice100=(InterventionTotalCostsPerPerson-100000*(InterventionQALYsPerPerson-ComparatorQALYsPerPerson))/ComparatorTotalCostsPerPerson

summ correct_qualityadjustedprice100, detail
gen p100_99=r(p99)
gen p100_1=r(p1)
gen outlier100=correct_qualityadjustedprice100>p100_99 | correct_qualityadjustedprice100<p100_1
summ correct_qualityadjustedprice100 if ~outlier100, detail

*************************************************
*COLI Laspeyres index price method and $150,000 VSLY
*************************************************
gen correct_qualityadjustedprice150=(InterventionTotalCostsPerPerson-150000*(InterventionQALYsPerPerson-ComparatorQALYsPerPerson))/ComparatorTotalCostsPerPerson

summ correct_qualityadjustedprice150, detail

gen p150_99=r(p99)
gen p150_1=r(p1)
gen outlier150=correct_qualityadjustedprice150>p150_99 | correct_qualityadjustedprice150<p150_1
summ correct_qualityadjustedprice150 if ~outlier150, detail


*************************************************
*PPQ index price method  - using the expression "TE" to refer to the PPQ index, based on prior version of the paper where TE refered to treatment endpoint.
*************************************************
gen qualityadjustedpriceTE=(InterventionTotalCostsPerPerson/InterventionQALYsPerPerson)/(ComparatorTotalCostsPerPerson/ComparatorQALYsPerPerson)
gen avgcost_perQALY=(InterventionTotalCostsPerPerson/InterventionQALYsPerPerson)

summ qualityadjustedpriceTE, detail
gen pTE_99=r(p99)
gen pTE_1=r(p1)
gen outlierTE=qualityadjustedpriceTE>pTE_99 | qualityadjustedpriceTE<pTE_1
summ qualityadjustedpriceTE, detail



/**********************************
15.  Hedonic analysis
**********************************/

regress lcostchange lsurvivalbenefit i.chapnum i.PubYear i.ntypeintervention if ~outlierTE  ,  cluster(chapnum)
eststo reg2


qreg costchange  survivalbenefit   i.chapnum  i.PubYear i.ntypeintervention if ~outlierTE, vce(robust) 
eststo reg5
qreg costchange  survivalbenefit   i.chapnum  i.PubYear i.ntypeintervention if ~outlierTE, quantile(.75) vce(robust) 
eststo reg7

/*************************
Table A1.  Hedonic Regression
**************************/

#delimit ;
esttab reg2 reg5 reg7 ,
nonumbers mtitles("(1)" "(2)" "(3)" )
 keep(lsurvivalbenefit survivalbenefit) se stats(N r2) starlevels(* 0.10 ** 0.05 *** 0.01) csv;
#delimit cr


 
/**********************************
16.  Hedonic analysis calculations continued
-Do a calculation of the value of a statistical life year implied by the hedonic regressions
**********************************/
est restore reg2
gen qualitychange=_b[lsurvivalbenefit]*lsurvivalbenefit
gen quality_adjustedintervention=lInterventionTotalCostsPerPerson-qualitychange
gen valuechange=exp(lInterventionTotalCostsPerPerson)-exp(quality_adjustedintervention)
gen QALYchange=InterventionQALYsPerPerson-ComparatorQALYsPerPerson
gen valueperlifeyear=valuechange/QALYchange
summ valueperlifeyear if ~outlierTE, detail
gen hedonicpriceincrease=exp(quality_adjustedintervention)/exp(lComparatorTotalCostsPerPerson)

summ hedonicpriceincrease, detail
gen pHO_99=r(p99)
gen pHO_1=r(p1)
gen outlierH=hedonicpriceincrease>pHO_99 | hedonicpriceincrease<pHO_1
summ hedonicpriceincrease if ~outlierH, detail
summ valueperlifeyear if ~outlierH, detail


est replay reg5
est restore reg5
gen quality_adjustedintervention5=InterventionTotalCostsPerPerson-_b[survivalbenefit]*survivalbenefit
gen hedonicpriceincrease5=quality_adjustedintervention5/ComparatorTotalCostsPerPerson
gen valueperlifeyear5=_b[survivalbenefit]
summ hedonicpriceincrease5, detail
gen pH5O_99=r(p99)
gen pH5O_1=r(p1)
gen outlierH5=hedonicpriceincrease5>pH5O_99 | hedonicpriceincrease5<pH5O_1
summ hedonicpriceincrease5 if ~outlierH5, detail


est replay reg7
est restore reg7
gen quality_adjustedintervention7=InterventionTotalCostsPerPerson-_b[survivalbenefit]*survivalbenefit
gen valueperlifeyear7=_b[survivalbenefit]
gen hedonicpriceincrease7=quality_adjustedintervention7/ComparatorTotalCostsPerPerson
summ hedonicpriceincrease7, detail
gen pH7O_99=r(p99)
gen pH7O_1=r(p1)
gen outlierH7=hedonicpriceincrease7>pH7O_99 | hedonicpriceincrease7<pH7O_1
summ hedonicpriceincrease7 if ~outlierH7, detail


*When doing comparisons across indexes only keep points where all 3 are observed.
gen misscorr_50=missing(correct_qualityadjustedprice50)
gen misscorr_50_2=missing(corr_qualityadjustedprice50_2)
gen misscorr_TE=missing(qualityadjustedpriceTE)
egen totmiss=rsum(misscorr_50 misscorr_50_2 misscorr_TE)
gen problemmissindex=totmiss==1 | totmiss==2


/**********************************
*15.  Display main output from CEAR database
****************************/


*************************************
*Table 2.  Price indexes for Table - Change to First Differencing
*************************************
for var hedonicpriceincrease5  hedonicpriceincrease7  corr_qualityadjustedprice50_2  corr_qualityadjustedprice100_2 corr_qualityadjustedprice150_2  qualityadjustedpriceTE  hedonicpriceincrease correct_qualityadjustedprice50 correct_qualityadjustedprice100 correct_qualityadjustedprice150: replace X= X-1

tabstat  correct_qualityadjustedprice50 if ~outlier50, stats(mean median p5 p95 sd n)

tabstat  correct_qualityadjustedprice100 if ~outlier100, stats(mean median p5 p95 sd n)

tabstat  correct_qualityadjustedprice150 if ~outlier150, stats(mean median p5 p95 sd n)

tabstat  corr_qualityadjustedprice50_2 if ~outlier50_2, stats(mean median p5 p95 sd n)

tabstat  corr_qualityadjustedprice100_2 if ~outlier100_2, stats(mean median p5 p95 sd n)

tabstat  corr_qualityadjustedprice150_2 if ~outlier150_2, stats(mean median p5 p95 sd n)

gen avg_qualityadjustedprice50=(correct_qualityadjustedprice50+corr_qualityadjustedprice50_2)/2  if ~missing(correct_qualityadjustedprice50) & ~missing(corr_qualityadjustedprice50_2)
gen avg_qualityadjustedprice100=(correct_qualityadjustedprice100+corr_qualityadjustedprice100_2)/2 if ~missing(correct_qualityadjustedprice100) & ~missing(corr_qualityadjustedprice100_2)
gen avg_qualityadjustedprice150=(correct_qualityadjustedprice150+corr_qualityadjustedprice150_2)/2 if ~missing(correct_qualityadjustedprice150) & ~missing(corr_qualityadjustedprice150_2)

tabstat  avg_qualityadjustedprice50 if ~outlier50_2 & ~outlier50, stats(mean median p5 p95 sd n)
tabstat  avg_qualityadjustedprice100 if ~outlier100_2 & ~outlier100, stats(mean median p5 p95 sd n)
tabstat  avg_qualityadjustedprice150 if  ~outlier150_2 & ~outlier150, stats(mean median p5 p95 sd n)


*************************************
*Table 3.  Price indexes for Table of alternatives
*************************************

tabstat  qualityadjustedpriceTE if ~outlierTE,  stats(mean median p5 p95 sd n)

tabstat  avgcost_perQALY if ~outlierTE, stats(mean median p5 p95 sd n)

tabstat  hedonicpriceincrease if ~outlierH, stats(mean median p5 p95 sd n)

tabstat  valueperlifeyear if ~outlierH, stats(mean median p5 p95 sd n)

tabstat  hedonicpriceincrease5 if ~outlierH5, stats(mean median p5 p95 sd n)

tabstat  valueperlifeyear5 if ~outlierH5, stats(mean median p5 p95 sd n)

tabstat  hedonicpriceincrease7 if ~outlierH7, stats(mean median p5 p95 sd n)

tabstat  valueperlifeyear7 if ~outlierH7, stats(mean median p5 p95 sd n)

*Store cleaned data for analysis.
save tempdata, replace


/******
Figure 1 - Scatterplot
*****/
use tempdata, clear
gen altvalue=avg_qualityadjustedprice100 
replace altvalue=. if altvalue<-1

twoway   (scatteri 0 0 -5 0 -5 5 0 5 0 0 , recast(area) color(blue*0.3) legend(label(1 "40% of Observations")))  (scatter avg_qualityadjustedprice100  qualityadjustedpriceTE, msize(.25) legend(label(2 "Observation")) ) ( lfit avg_qualityadjustedprice100  qualityadjustedpriceTE,  lpattern(dashed) color(blue) legend(label(3 "Fitted Line")))  ( line avg_qualityadjustedprice100  altvalue, color(red) legend(label(4 "45 Degree Line")))   if ~outlier100_2 & ~outlier100 & abs(avg_qualityadjustedprice100)<5 & abs(qualityadjustedpriceTE)<5, yline(0, lstyle(grid)  lcolor(black)) xline(0, lstyle(grid) lcolor(black)) xlabel(-1(1)5) ylabel(-5(1)5)  ytitle("Utility-Based Index (VSLY 100k Dollars)"  "Price Change")  xtitle("Price-Per-QALY Index" "Price Change") aspectratio(1)
graph export "$outputpath/twoway_scatter.png", replace

gen pospos=avg_qualityadjustedprice100>=0 &  qualityadjustedpriceTE>=0
gen posneg=avg_qualityadjustedprice100>=0 &  qualityadjustedpriceTE<0
gen negneg=avg_qualityadjustedprice100<0 &  qualityadjustedpriceTE<0
gen negpos=avg_qualityadjustedprice100<0 &  qualityadjustedpriceTE>=0
gen cat=1*pospos+2*posneg+3*negneg+4*negpos 

gen below45=avg_qualityadjustedprice100<qualityadjustedpriceTE if ~missing(avg_qualityadjustedprice100) | ~missing(qualityadjustedpriceTE)
replace cat=. if missing(avg_qualityadjustedprice100) | missing(qualityadjustedpriceTE)
tab cat if ~outlier100_2 & ~outlier100 

/******
Figure 2.  Histogram of estimates.
*****/
use tempdata, clear

scalar winvalue=5
gen alt_qualityadjustedprice100=avg_qualityadjustedprice100
replace alt_qualityadjustedprice100=-1*winvalue if avg_qualityadjustedprice100<-1*winvalue
replace alt_qualityadjustedprice100=winvalue if avg_qualityadjustedprice100>winvalue


gen alt_qualityadjustedprice50=avg_qualityadjustedprice50
replace alt_qualityadjustedprice50=-1*winvalue if avg_qualityadjustedprice50<-1*winvalue
replace alt_qualityadjustedprice50=winvalue if avg_qualityadjustedprice50>winvalue

gen alt_qualityadjustedprice150=avg_qualityadjustedprice150
replace alt_qualityadjustedprice150=-1*winvalue if avg_qualityadjustedprice150<-1*winvalue
replace alt_qualityadjustedprice150=winvalue if avg_qualityadjustedprice150>winvalue
replace alt_qualityadjustedprice150=. if missing(avg_qualityadjustedprice150)
replace alt_qualityadjustedprice50=. if missing(avg_qualityadjustedprice50)
replace alt_qualityadjustedprice100=. if missing(avg_qualityadjustedprice100)

gen altqualityadjustedpriceTE=qualityadjustedpriceTE 
replace altqualityadjustedpriceTE=winvalue if qualityadjustedpriceTE >winvalue
replace altqualityadjustedpriceTE=-1*winvalue if qualityadjustedpriceTE<-1*winvalue
replace altqualityadjustedpriceTE=. if missing(qualityadjustedpriceTE)
summ alt_qualityadjustedprice100 if ~outlier100_2 & ~outlier100 & ~problemmissindex &  alt_qualityadjustedprice100<=1

twoway (histogram  alt_qualityadjustedprice150, width(.10) color(blue%30)) ///        
       (histogram alt_qualityadjustedprice50, width(.10)color(red%20)) if ~outlier50_2 & ~outlier50 & ~outlier150_2 & ~outlier150 & ~problemmissindex, ///   
       legend(order(1 "VSLY $150k" 2 "VSLY $50k" )) title("Average Utility-Based Price Change") xlabel(-5(1)5)

graph export "$outputpath\histogram_indexes.png", replace



/****************
Table 4.  Select Examples used 
**************/

use tempdata, clear
order CCS*

keep if RatioID=="2012-01-08421-07" | RatioID=="2011-01-08148-05" | RatioID=="2015-01-20969-03"| RatioID=="2012-01-08421-07" | RatioID=="2005-01-12496-02" | RatioID=="2007-01-03094-01" | RatioID=="2015-01-18503-10"
order InterventionTotalCostsPerPerson  ComparatorTotalCostsPerPerson ComparatorQALYsPerPerson   InterventionQALYsPerPerson correct_qualityadjustedprice100 corr_qualityadjustedprice100_2 qualityadjustedpriceTE  InterventionPhrase ComparatorPhrase avg_qualityadjustedprice100 ICERFinaladjust ICER 
tab InterventionPhrase outlier100 

**************************
*Table 5.  quality-adjusted prices
****************************
use tempdata, clear

table chapter if ~outlier100_2 & ~outlier100 , c(n avg_qualityadjustedprice100 mean avg_qualityadjustedprice100 median avg_qualityadjustedprice100) format(%12.0g)

table chapter if ~outlier100_2 & ~outlier100 & Rating>=5, c(n avg_qualityadjustedprice100 mean avg_qualityadjustedprice100 median avg_qualityadjustedprice100)

table typeintervention if ~outlier100_2 & ~outlier100, c(n avg_qualityadjustedprice100 mean avg_qualityadjustedprice100 median avg_qualityadjustedprice100)

table typeintervention if ~outlier100_2 & ~outlier100 & Rating>=5, c(n avg_qualityadjustedprice100 mean avg_qualityadjustedprice100 median avg_qualityadjustedprice100)


table typesponsor if ~outlier100_2 & ~outlier100, c(n avg_qualityadjustedprice100 mean avg_qualityadjustedprice100 median avg_qualityadjustedprice100)

table typesponsor if ~outlier100_2 & ~outlier100 & Rating>=5, c(n avg_qualityadjustedprice100 mean avg_qualityadjustedprice100 median avg_qualityadjustedprice100)

table studytype if ~outlier100_2 & ~outlier100, c(n avg_qualityadjustedprice100 mean avg_qualityadjustedprice100 median avg_qualityadjustedprice100)

table studytype if ~outlier100_2 & ~outlier100 & Rating>=5, c(n avg_qualityadjustedprice100 mean avg_qualityadjustedprice100 median avg_qualityadjustedprice100)




/**************************
Appendix Table A2.  Explanation of extremes in technology
**************************/
use tempdata, clear


gen ICERconstructed=(InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)/(InterventionQALYsPerPerson-ComparatorQALYsPerPerson)
gen poortechnology=((InterventionQALYsPerPerson-ComparatorQALYsPerPerson)<0) & ((InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)<0)  
gen superiortechnology=((InterventionQALYsPerPerson-ComparatorQALYsPerPerson)>=0) & (InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)<0 
gen inferiortechnology= ((InterventionQALYsPerPerson-ComparatorQALYsPerPerson)<0) & ((InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)>=0) 
gen normaltechnology= ((InterventionQALYsPerPerson-ComparatorQALYsPerPerson)>=0 ) & ((InterventionTotalCostsPerPerson-ComparatorTotalCostsPerPerson)>=0) 


gen extremelyeffective=(ICERconstructed<1000 & ICERconstructed>=0)*normaltechnology
gen highlyeffective=(ICERconstructed<10000 & ICERconstructed>=1000)*normaltechnology
gen moderatelyeffective=(ICERconstructed<50000 & ICERconstructed>=10000)*normaltechnology
gen effective=(ICERconstructed<100000 & ICERconstructed>=50000)*normaltechnology
gen loweffective=(ICERconstructed>100000 & ICERconstructed<=200000)*normaltechnology
gen ineffective=(ICERconstructed>200000)*normaltechnology
gen lunadjustedgrowth=log(InterventionTotalCostsPerPerson/ComparatorTotalCostsPerPerson)
gen unadjustedgrowth=(InterventionTotalCostsPerPerson/ComparatorTotalCostsPerPerson)
gen totalcheck=poortechnology+superiortechnology+inferiortechnology+normaltechnology

tab normaltechnology
tab inferiortechnology
tab superiortechnology
tab poortechnology

gen quadrant=3*poortechnology+4*inferiortechnology+1*normaltechnology+2*superiortechnology
replace quadrant=. if quadrant==0

label define quadrantlabels 1 "Increase Cost & Increase QALY" 2 "Decrease Cost & Increase QALY" 3 "Decrease Cost & Decrease QALY" 4 "Increase Cost & Decrease QALY"
label values quadrant quadrantlabels

gen effectiveness=1*extremelyeffective+2*highlyeffective+3*moderatelyeffective+4*effective+5*loweffective+6*ineffective 
label define effectivelabels 1 "ICER<$1000 & ICER>=0" 2 "ICER<$10000 & ICER>=$1000" 3 "ICER<$50000 & ICER>=$10000" 4 "ICER<$100000 & ICER>=$50000" 5 "ICER<$200000 & ICER>=$100000" 6 "ICER>=$200000"
label values effectiveness effectivelabels


label variable superiortechnology "Decrease Cost & Increase QALY"
label variable normaltechnology "Increase Cost & Increase QALY"
label variable poortechnology "Decrease Cost & Decrease QALY"
label variable inferiortechnology "Increase Cost & Decrease QALY"

label variable extremelyeffective "ICER<$1000 & ICER>=0"
label variable highlyeffective "ICER<$10000 & ICER>=$1000"
label variable moderatelyeffective "ICER<$50000 & ICER>=$10000"
label variable effective "ICER<$100000 & ICER>=$50000"
label variable loweffective "ICER<$200000 & ICER>=$100000"
label variable ineffective "ICER>=$200000"
summ ICERconstructed if normaltechnology, detail

/**************************
Table A2.  Explanation of extremes in technology
**************************/
tabstat avg_qualityadjustedprice100 if ~outlier100_2 & ~outlier100, by(quadrant) stats(n mean median p5 p95 sd) labelwidth(70)
tabstat avg_qualityadjustedprice100 if ~outlier100_2 & ~outlier100 & ( quadrant==1), by( effectiveness) stats(n mean median  p5 p95 sd) labelwidth(50)




/**********
*Construct aggregate and chapter specific indexes - using spending weights
**********/
use tempdata, clear

summ avg_qualityadjustedprice100  if ~outlier100_2 & ~outlier100, detail
scalar aggregateprice100=r(mean)
summ avg_qualityadjustedprice50  if ~outlier50_2 & ~outlier50, detail
scalar aggregateprice50=r(mean)
summ avg_qualityadjustedprice150  if ~outlier150_2 & ~outlier150, detail
scalar aggregateprice150=r(mean)

*Diffusion Rate
scalar difflow=.0188877
scalar diffmed=.0283208
scalar diffhigh=.0362048

/*****************************
Table 6. Arithmetic Average
******************************/
display hcsa_overalldis_pricegrowth[1]
scalar low_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+aggregateprice50))-1
display low_agg_qualadj50_growth
scalar low_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+aggregateprice100))-1
display low_agg_qualadj100_growth
scalar low_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+aggregateprice150))-1
display low_agg_qualadj150_growth

scalar med_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+aggregateprice50))-1
display med_agg_qualadj50_growth
scalar med_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+aggregateprice100))-1
display med_agg_qualadj100_growth
scalar med_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+aggregateprice150))-1
display med_agg_qualadj150_growth

scalar high_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+aggregateprice50))-1
display high_agg_qualadj50_growth
scalar high_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+aggregateprice100))-1
display high_agg_qualadj100_growth
scalar high_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+aggregateprice150))-1
display high_agg_qualadj150_growth


gen qualchap_price50=.
gen qualchap_price100=.
gen qualchap_price150=.

forvalues k = 1/18 {

summ avg_qualityadjustedprice50  if ~outlier50_2 & ~outlier50 & chapnum==`k', detail
replace qualchap_price50=r(mean) if chapnum==`k'

summ avg_qualityadjustedprice100  if ~outlier100_2 & ~outlier100 & chapnum==`k', detail
replace qualchap_price100=r(mean) if chapnum==`k'

summ avg_qualityadjustedprice150  if ~outlier150_2 & ~outlier150 & chapnum==`k', detail
replace qualchap_price150=r(mean) if chapnum==`k'

}



drop if missing(chapnum)
sort chapnum
by chapnum: gen mark=_n==1


/***********************************************
Table 7 Weighted - Arithmetic Average, Weighted
*********************************************/
table CCSChapter if ~missing(avg_qualityadjustedprice100) & ~outlier100_2 & ~outlier100, c(n share_chapter2000)

gen anndispricegrowth=hcsa_dis_pricegrowth^(1/17)-1

keep if mark
table CCSChapter, c(mean share_chapter2000 mean anndispricegrowth mean qualchap_price50 mean qualchap_price100 mean qualchap_price150)

table CCSChapter, c(mean share_chapter2000 mean share_chapter2017)

gen low_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+qualchap_price50))
gen low_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+qualchap_price100))
gen low_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+qualchap_price150))

gen med_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+qualchap_price50))
gen med_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+qualchap_price100))
gen med_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+qualchap_price150))

gen high_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+qualchap_price50))
gen high_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+qualchap_price100))
gen high_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+qualchap_price150))


gen weight=share_chapter2000

egen agglow_dis_qualadj50=sum(low_dis_qualadj50*weight)
display agglow_dis_qualadj50[1]
egen agglow_dis_qualadj100=sum(low_dis_qualadj100*weight)
display agglow_dis_qualadj100[1]
egen agglow_dis_qualadj150=sum(low_dis_qualadj150*weight)
display agglow_dis_qualadj150[1]

egen aggmed_dis_qualadj50=sum(med_dis_qualadj50*weight)
display aggmed_dis_qualadj50[1]
egen aggmed_dis_qualadj100=sum(med_dis_qualadj100*weight)
display aggmed_dis_qualadj100[1]
egen aggmed_dis_qualadj150=sum(med_dis_qualadj150*weight)
display aggmed_dis_qualadj150[1]

egen agghigh_dis_qualadj50=sum(high_dis_qualadj50*weight)
display agghigh_dis_qualadj50[1]
egen agghigh_dis_qualadj100=sum(high_dis_qualadj100*weight)
display agghigh_dis_qualadj100[1]
egen agghigh_dis_qualadj150=sum(high_dis_qualadj150*weight)
display agghigh_dis_qualadj150[1]

for var low_dis_qualadj50-high_dis_qualadj150  agglow_dis_qualadj50-agghigh_dis_qualadj150: replace X=X-1

/***********************************************
Table 7 Weighted - Arithmetic Average, Weighted
*********************************************/

table CCSChapter, c(mean share_chapter2000 mean anndispricegrowth mean med_dis_qualadj50 mean med_dis_qualadj100 mean med_dis_qualadj150)

tabstat agglow_dis_qualadj50 agglow_dis_qualadj100 agglow_dis_qualadj150, stats(mean)
tabstat aggmed_dis_qualadj50 aggmed_dis_qualadj100 aggmed_dis_qualadj150, stats(mean)
tabstat agghigh_dis_qualadj50 agghigh_dis_qualadj100 agghigh_dis_qualadj150, stats(mean)







/*
/**********
Table 6.  Bootstrap estimates for using a set seed.  - bootstrap is commented out to reduce runtime.
**************/
use tempdata, clear
bootstrap mean=r(mean), reps(1000) cluster(ArticleID) seed(12345)  saving(mybs1, replace): summarize avg_qualityadjustedprice50 if ~outlier50_2 & ~outlier50, detail
bootstrap mean=r(mean), reps(1000) cluster(ArticleID)  seed(12345) saving(mybs2, replace): summarize avg_qualityadjustedprice100 if ~outlier100_2 & ~outlier100, detail
bootstrap mean=r(mean), reps(1000) cluster(ArticleID)  seed(12345) saving(mybs3, replace): summarize avg_qualityadjustedprice150 if ~outlier150_2 & ~outlier150, detail





/***********
Table 7.  Bootstrap disease weighted estimates using a set seed  - bootstrap is commented out to reduce runtime.
************/

use tempdata, clear

capture program drop myboot
program define myboot, rclass
 preserve
 bsample, cluster(ArticleID)

 summ avg_qualityadjustedprice100  if ~outlier100_2 & ~outlier100, detail
scalar aggregateprice100=r(mean)

summ avg_qualityadjustedprice50  if ~outlier50_2 & ~outlier50, detail
scalar aggregateprice50=r(mean)

summ avg_qualityadjustedprice150  if ~outlier150_2 & ~outlier150, detail
scalar aggregateprice150=r(mean)

scalar difflow=.0188877
scalar diffmed=.0283208
scalar diffhigh=.0362048


scalar low_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+aggregateprice50))-1
display low_agg_qualadj50_growth
scalar low_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+aggregateprice100))-1
display low_agg_qualadj100_growth
scalar low_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+aggregateprice150))-1
display low_agg_qualadj150_growth


scalar med_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+aggregateprice50))-1
display med_agg_qualadj50_growth
scalar med_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+aggregateprice100))-1
display med_agg_qualadj100_growth
scalar med_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+aggregateprice150))-1
display med_agg_qualadj150_growth

scalar high_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+aggregateprice50))-1
display high_agg_qualadj50_growth
scalar high_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+aggregateprice100))-1
display high_agg_qualadj100_growth
scalar high_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+aggregateprice150))-1
display high_agg_qualadj150_growth


gen qualchap_price50=.
gen qualchap_price100=.
gen qualchap_price150=.

forvalues k = 1/18 {

summ avg_qualityadjustedprice50  if ~outlier50_2 & ~outlier50 & chapnum==`k', detail
replace qualchap_price50=r(mean) if chapnum==`k'

summ avg_qualityadjustedprice100  if ~outlier100_2 & ~outlier100 & chapnum==`k', detail
replace qualchap_price100=r(mean) if chapnum==`k'

summ avg_qualityadjustedprice150  if ~outlier150_2 & ~outlier150 & chapnum==`k', detail
replace qualchap_price150=r(mean) if chapnum==`k'
}
drop if missing(chapnum)
sort chapnum
by chapnum: gen mark=_n==1
keep if mark

gen low_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+qualchap_price50))
gen low_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+qualchap_price100))
gen low_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+qualchap_price150))

gen med_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+qualchap_price50))
gen med_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+qualchap_price100))
gen med_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+qualchap_price150))

gen high_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+qualchap_price50))
gen high_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+qualchap_price100))
gen high_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+qualchap_price150))

gen weight=share_chapter2000
egen agglow_dis_qualadj50=sum(low_dis_qualadj50*weight)
egen agglow_dis_qualadj100=sum(low_dis_qualadj100*weight)
egen agglow_dis_qualadj150=sum(low_dis_qualadj150*weight)

egen aggmed_dis_qualadj50=sum(med_dis_qualadj50*weight)
egen aggmed_dis_qualadj100=sum(med_dis_qualadj100*weight)
egen aggmed_dis_qualadj150=sum(med_dis_qualadj150*weight)

egen agghigh_dis_qualadj50=sum(high_dis_qualadj50*weight)
egen agghigh_dis_qualadj100=sum(high_dis_qualadj100*weight)
egen agghigh_dis_qualadj150=sum(high_dis_qualadj150*weight)

return scalar agglow_qualadj50=agglow_dis_qualadj50[1]-1
return scalar agglow_qualadj100=agglow_dis_qualadj100[1]-1
return scalar agglow_qualadj150=agglow_dis_qualadj150[1]-1

return scalar aggmed_qualadj50=aggmed_dis_qualadj50[1]-1
return scalar aggmed_qualadj100=aggmed_dis_qualadj100[1]-1
return scalar aggmed_qualadj150=aggmed_dis_qualadj150[1]-1

return scalar agghigh_qualadj50=agghigh_dis_qualadj50[1]-1
return scalar agghigh_qualadj100=agghigh_dis_qualadj100[1]-1
return scalar agghigh_qualadj150=agghigh_dis_qualadj150[1]-1

restore
end


simulate bootlow_50=r(agglow_qualadj50) bootlow_100=r(agglow_qualadj100) bootlow_150=r(agglow_qualadj150) bootmed_50=r(aggmed_qualadj50) bootmed_100=r(aggmed_qualadj100) bootmed_150=r(aggmed_qualadj150)  boothigh_50=r(agghigh_qualadj50) boothigh_100=r(agghigh_qualadj100) boothigh_150=r(agghigh_qualadj150), reps(1000) seed(12345)  : myboot


tabstat bootlow_50 bootlow_100 bootlow_150, stats(mean p5 p95 sd)
tabstat bootmed_50 bootmed_100 bootmed_150, stats(mean  p5 p95 sd)
tabstat boothigh_50 boothigh_100 boothigh_150, stats(mean  p5 p95 sd)
*/



/*Table A6  - Unweighted*/
use tempdata, clear

summ avg_qualityadjustedprice100  if ~outlier100_2 & ~outlier100, detail
scalar aggregateprice100=r(mean)

summ avg_qualityadjustedprice50  if ~outlier50_2 & ~outlier50, detail
scalar aggregateprice50=r(mean)

summ avg_qualityadjustedprice150  if ~outlier150_2 & ~outlier150, detail
scalar aggregateprice150=r(mean)

scalar difflow=.0188877
scalar diffmed=.0283208
scalar diffhigh=.0362048
scalar substitution=2


gen hcsaagg=(hcsa_overalldis_pricegrowth[1])^(1/17)


gen ind_med_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice50)) if ~outlier50_2 & ~outlier50

gen ind_med_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice100)) if ~outlier100_2 & ~outlier100

gen ind_med_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice150)) if ~outlier150_2 & ~outlier150


summ ind_med_agg_qualadj100_growth if ind_med_agg_qualadj100_growth>=0 , detail

replace ind_med_agg_qualadj50_growth=. if ind_med_agg_qualadj50_growth<0
replace ind_med_agg_qualadj100_growth=. if ind_med_agg_qualadj100_growth<0
replace ind_med_agg_qualadj150_growth=. if ind_med_agg_qualadj150_growth<0

gen newind_med_agg_qualadj50_growth=ind_med_agg_qualadj50_growth^(1-substitution)
gen newind_med_agg_qualadj100_growth=ind_med_agg_qualadj100_growth^(1-substitution)
gen newind_med_agg_qualadj150_growth=ind_med_agg_qualadj150_growth^(1-substitution)

egen totconstant50=sum(~missing(ind_med_agg_qualadj50_growth))
egen totind_med_agg_qualadj50_growth=sum(newind_med_agg_qualadj50_growth)


egen totconstant100=sum(~missing(ind_med_agg_qualadj100_growth))
egen totind_med_agg_qualadj100_growth=sum(newind_med_agg_qualadj100_growth)

egen totconstant150=sum(~missing(ind_med_agg_qualadj150_growth))
egen totind_med_agg_qualadj150_growth=sum(newind_med_agg_qualadj150_growth)


gen ces_index50=(totind_med_agg_qualadj50_growth^(1/(1-substitution)))/(totconstant50^(1/(1-substitution)))-1
summ ces_index50, detail

gen ces_index100=(totind_med_agg_qualadj100_growth^(1/(1-substitution)))/(totconstant100^(1/(1-substitution)))-1
summ ces_index100, detail

gen ces_index150=(totind_med_agg_qualadj150_growth^(1/(1-substitution)))/(totconstant150^(1/(1-substitution)))-1
summ ces_index150, detail

gen share50=1/totconstant50
gen obs50=~missing(ind_med_agg_qualadj50_growth)
egen logcobbdouglas50=sum(share50*log(ind_med_agg_qualadj50_growth/share50)*obs50)
gen cobbdouglas50=exp(logcobbdouglas50)/totconstant50-1
summ cobbdouglas50, detail


gen share100=1/totconstant100
gen obs100=~missing(ind_med_agg_qualadj100_growth)
egen logcobbdouglas100=sum(share100*log(ind_med_agg_qualadj100_growth/share100)*obs100)
gen cobbdouglas100=exp(logcobbdouglas100)/totconstant100-1
summ cobbdouglas100, detail

gen share150=1/totconstant150
gen obs150=~missing(ind_med_agg_qualadj150_growth)
egen logcobbdouglas150=sum(share150*log(ind_med_agg_qualadj150_growth/share150)*obs150)
gen cobbdouglas150=exp(logcobbdouglas150)/totconstant150-1
summ cobbdouglas150, detail

*Table A6 CES unweighted
tabstat ces_index50 ces_index100 ces_index150, stats(mean)

*Table A6 Cobb Douglas unweighted
tabstat cobbdouglas50 cobbdouglas100 cobbdouglas150, stats(mean)




/**********
*Table A6.  Alternative functional forms. - Construct aggregate and chapter specific indexes - using spending weights
**************
The "options" below correspond to the different lines in Table A6.  For example, if option=="3_4_5_6" then the corresponding results for
lines 3,4,5, and 6 in Table A6 will be provided.

**********/
use tempdata, clear


/*
select option to be run for table.  Code produces both CES and Cobb Douglas for each run.
Currently the option is set for line 16 of the appendix table.
*/
local option="16"

if "`option'"=="3_4_5_6"   {   

scalar sigma=2
}

if "`option'"=="7"   {   

scalar sigma=3
}


else if "`option'"=="8_9" {

keep if highincome
scalar sigma=2

}   

else if "`option'"=="10" {

keep if highincome
scalar sigma=3

}   

else if "`option'"=="11_12" {

keep if highincome
scalar sigma=2
replace avg_qualityadjustedprice100=. if  (avg_qualityadjustedprice100>0)
replace avg_qualityadjustedprice150=. if  (avg_qualityadjustedprice150>0)
replace avg_qualityadjustedprice50=. if  (avg_qualityadjustedprice50>0)

}  


else if "`option'"=="13" {

keep if highincome
scalar sigma=3
replace avg_qualityadjustedprice100=. if  (avg_qualityadjustedprice100>0)
replace avg_qualityadjustedprice150=. if  (avg_qualityadjustedprice150>0)
replace avg_qualityadjustedprice50=. if  (avg_qualityadjustedprice50>0)

}


 else if "`option'"=="14_15" {

 scalar sigma=2
summ avg_qualityadjustedprice100, detail
gen p95_100=r(p95)
gen p5_100=r(p5)
replace avg_qualityadjustedprice100=. if (avg_qualityadjustedprice100<p5_100) | (avg_qualityadjustedprice100>0)


summ avg_qualityadjustedprice150, detail
gen p95_150=r(p95)
gen p5_150=r(p5)
replace avg_qualityadjustedprice150=. if (avg_qualityadjustedprice150<p5_150) | (avg_qualityadjustedprice150>0)

summ avg_qualityadjustedprice50, detail
gen p95_50=r(p95)
gen p5_50=r(p5)
replace avg_qualityadjustedprice50=. if (avg_qualityadjustedprice50<p5_50)  | (avg_qualityadjustedprice50>0)

}


 else if "`option'"=="16" {

 scalar sigma=3
summ avg_qualityadjustedprice100, detail
gen p95_100=r(p95)
gen p5_100=r(p5)
replace avg_qualityadjustedprice100=. if (avg_qualityadjustedprice100<p5_100) | (avg_qualityadjustedprice100>0)



summ avg_qualityadjustedprice150, detail
gen p95_150=r(p95)
gen p5_150=r(p5)
replace avg_qualityadjustedprice150=. if (avg_qualityadjustedprice150<p5_150) | (avg_qualityadjustedprice150>0)

summ avg_qualityadjustedprice50, detail
gen p95_50=r(p95)
gen p5_50=r(p5)
replace avg_qualityadjustedprice50=. if (avg_qualityadjustedprice50<p5_50)  | (avg_qualityadjustedprice50>0)

}



summ avg_qualityadjustedprice100  if ~outlier100_2 & ~outlier100, detail
scalar aggregateprice100=r(mean)
scalar aggobs100=r(N)



summ avg_qualityadjustedprice50  if ~outlier50_2 & ~outlier50, detail
scalar aggregateprice50=r(mean)
scalar aggobs50=r(N)

summ avg_qualityadjustedprice150  if ~outlier150_2 & ~outlier150, detail
scalar aggregateprice150=r(mean)
scalar aggobs150=r(N)

scalar difflow=.0188877
scalar diffmed=.0283208
scalar diffhigh=.0362048

display hcsa_overalldis_pricegrowth[1]

gen low_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+avg_qualityadjustedprice50)) if ~outlier50_2 & ~outlier50
gen  low_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+avg_qualityadjustedprice100)) if ~outlier100_2 & ~outlier100
gen  low_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-difflow)+difflow*(1+avg_qualityadjustedprice150)) if ~outlier150_2 & ~outlier150


gen med_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice50)) if ~outlier50_2 & ~outlier50
gen med_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice100)) if ~outlier100_2 & ~outlier100
gen med_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice150)) if ~outlier150_2 & ~outlier150

gen high_agg_qualadj50_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+avg_qualityadjustedprice50)) if ~outlier50_2 & ~outlier50
gen  high_agg_qualadj100_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+avg_qualityadjustedprice100)) if ~outlier100_2 & ~outlier100

gen high_agg_qualadj150_growth=((hcsa_overalldis_pricegrowth[1])^(1/17)*(1-diffhigh)+diffhigh*(1+avg_qualityadjustedprice150)) if ~outlier150_2 & ~outlier150



        foreach x of varlist low_agg_qualadj50_growth-high_agg_qualadj150_growth {

		replace `x'=. if `x'<0
		gen index=`x'^(1-sigma)
		egen totconstant=sum(~missing(`x'))
		egen totindex=sum(index)
		gen agg`x'=(totindex^(1/(1-sigma)))/(totconstant^(1/(1-sigma)))
		gen logcd=(1/totconstant)*ln(`x'/(1/totconstant))
		egen agglogcd=sum(logcd)
		gen cd`x'=exp(agglogcd)/totconstant
		drop index totconstant totindex logcd agglogcd
        }


/*****************************
Table A6 Cobb-Douglas, unweighted 
****************************/

        foreach x of varlist low_agg_qualadj50_growth-high_agg_qualadj150_growth {
		display cd`x'[1]-1
}
summ med_agg_qualadj100_growth, detail
gen obs_cd_uw_100=r(N)
display obs_cd_uw_100
/*****************************
Table A6 CES, unweighted 
****************************/

        foreach x of varlist low_agg_qualadj50_growth-high_agg_qualadj150_growth {
		display agg`x'[1]-1
}



drop if missing(chapnum)
sort chapnum
by chapnum: gen mark=_n==1

table CCSChapter if ~missing(avg_qualityadjustedprice100) & ~outlier100_2 & ~outlier100, c(n share_chapter2000)


gen anndispricegrowth=hcsa_dis_pricegrowth^(1/17)-1


gen low_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+avg_qualityadjustedprice50)) if ~outlier50_2 & ~outlier50
gen low_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+avg_qualityadjustedprice100)) if ~outlier100_2 & ~outlier100
gen low_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-difflow)+difflow*(1+avg_qualityadjustedprice150)) if ~outlier150_2 & ~outlier150

gen med_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice50)) if ~outlier50_2 & ~outlier50
gen med_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice100)) if ~outlier100_2 & ~outlier100
gen med_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-diffmed)+diffmed*(1+avg_qualityadjustedprice150)) if ~outlier150_2 & ~outlier150

gen high_dis_qualadj50=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+avg_qualityadjustedprice50)) if ~outlier50_2 & ~outlier50
gen high_dis_qualadj100=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+avg_qualityadjustedprice100)) if ~outlier100_2 & ~outlier100
gen high_dis_qualadj150=((hcsa_dis_pricegrowth)^(1/17)*(1-diffhigh)+diffhigh*(1+avg_qualityadjustedprice150)) if ~outlier150_2 & ~outlier150

egen checkshare=sum(share_chapter2000)
summ checkshare, detail
gen weight=share_chapter2000




sort CCSChapter

        foreach x of varlist low_dis_qualadj50-high_dis_qualadj150 {

		by CCSChapter: replace `x'=. if `x'<0
		by CCSChapter: gen index=`x'^(1-sigma)
		by CCSChapter: egen totconstant=sum(~missing(`x'))
		by CCSChapter: egen totindex=sum(index)
		by CCSChapter: gen agg`x'=(totindex^(1/(1-sigma)))/(totconstant^(1/(1-sigma)))
		by CCSChapter: gen logcd=(1/totconstant)*ln(`x'/(1/totconstant))
		by CCSChapter: egen agglogcd=sum(logcd)
		by CCSChapter: gen cd`x'=exp(agglogcd)/totconstant
		
		drop index totconstant totindex logcd agglogcd
        }

summ med_dis_qualadj100  if ~outlier100_2 & ~outlier100, detail
scalar aggweightedobs100=r(N)

		
keep if mark


/******************
Table A6.  Weighted aggregate CES index
**********************/
foreach x of varlist low_dis_qualadj50-high_dis_qualadj150 {		
		egen totagg`x'=sum(agg`x'*weight)
}
	foreach x of varlist low_dis_qualadj50-high_dis_qualadj150 {		

	display totagg`x'[1]-1
}


/******************
Table A6.  Weighted aggregate Cobb-Douglas index
**********************/		
foreach x of varlist low_dis_qualadj50-high_dis_qualadj150 {		
		egen totcd`x'=sum(cd`x'*weight)
}

	foreach x of varlist low_dis_qualadj50-high_dis_qualadj150  {		
	
	display totcd`x'[1]-1
}









